Module entities

Module entities 

Structs

Address
FTM Schema: Address
AddressBuilder
Use builder syntax to set the inputs and finish with build().
Airplane
FTM Schema: Airplane
AirplaneBuilder
Use builder syntax to set the inputs and finish with build().
Article
FTM Schema: Article
ArticleBuilder
Use builder syntax to set the inputs and finish with build().
Asset
FTM Schema: Asset
AssetBuilder
Use builder syntax to set the inputs and finish with build().
Associate
FTM Schema: Associate
AssociateBuilder
Use builder syntax to set the inputs and finish with build().
Audio
FTM Schema: Audio
AudioBuilder
Use builder syntax to set the inputs and finish with build().
BankAccount
FTM Schema: Bank account
BankAccountBuilder
Use builder syntax to set the inputs and finish with build().
Call
FTM Schema: Call
CallBuilder
Use builder syntax to set the inputs and finish with build().
CallForTenders
FTM Schema: Call for tenders
CallForTendersBuilder
Use builder syntax to set the inputs and finish with build().
Company
FTM Schema: Company
CompanyBuilder
Use builder syntax to set the inputs and finish with build().
Contract
FTM Schema: Contract
ContractAward
FTM Schema: Contract award
ContractAwardBuilder
Use builder syntax to set the inputs and finish with build().
ContractBuilder
Use builder syntax to set the inputs and finish with build().
CourtCase
FTM Schema: Court case
CourtCaseBuilder
Use builder syntax to set the inputs and finish with build().
CourtCaseParty
FTM Schema: Case party
CourtCasePartyBuilder
Use builder syntax to set the inputs and finish with build().
CryptoWallet
FTM Schema: Cryptocurrency wallet
CryptoWalletBuilder
Use builder syntax to set the inputs and finish with build().
Debt
FTM Schema: Debt
DebtBuilder
Use builder syntax to set the inputs and finish with build().
Directorship
FTM Schema: Directorship
DirectorshipBuilder
Use builder syntax to set the inputs and finish with build().
Document
FTM Schema: File
DocumentBuilder
Use builder syntax to set the inputs and finish with build().
Documentation
FTM Schema: Documentation
DocumentationBuilder
Use builder syntax to set the inputs and finish with build().
EconomicActivity
FTM Schema: Customs declaration
EconomicActivityBuilder
Use builder syntax to set the inputs and finish with build().
Email
FTM Schema: E-Mail
EmailBuilder
Use builder syntax to set the inputs and finish with build().
Employment
FTM Schema: Employment
EmploymentBuilder
Use builder syntax to set the inputs and finish with build().
Event
FTM Schema: Event
EventBuilder
Use builder syntax to set the inputs and finish with build().
Family
FTM Schema: Family
FamilyBuilder
Use builder syntax to set the inputs and finish with build().
Folder
FTM Schema: Folder
FolderBuilder
Use builder syntax to set the inputs and finish with build().
HyperText
FTM Schema: Web page
HyperTextBuilder
Use builder syntax to set the inputs and finish with build().
Identification
FTM Schema: Identification
IdentificationBuilder
Use builder syntax to set the inputs and finish with build().
Image
FTM Schema: Image
ImageBuilder
Use builder syntax to set the inputs and finish with build().
LegalEntity
FTM Schema: Legal entity
LegalEntityBuilder
Use builder syntax to set the inputs and finish with build().
License
FTM Schema: License
LicenseBuilder
Use builder syntax to set the inputs and finish with build().
Membership
FTM Schema: Membership
MembershipBuilder
Use builder syntax to set the inputs and finish with build().
Mention
FTM Schema: Mention
MentionBuilder
Use builder syntax to set the inputs and finish with build().
Message
FTM Schema: Message
MessageBuilder
Use builder syntax to set the inputs and finish with build().
Note
FTM Schema: Note
NoteBuilder
Use builder syntax to set the inputs and finish with build().
Occupancy
FTM Schema: Occupancy
OccupancyBuilder
Use builder syntax to set the inputs and finish with build().
Organization
FTM Schema: Organization
OrganizationBuilder
Use builder syntax to set the inputs and finish with build().
Ownership
FTM Schema: Ownership
OwnershipBuilder
Use builder syntax to set the inputs and finish with build().
Package
FTM Schema: Package
PackageBuilder
Use builder syntax to set the inputs and finish with build().
Page
FTM Schema: Page
PageBuilder
Use builder syntax to set the inputs and finish with build().
Pages
FTM Schema: Document
PagesBuilder
Use builder syntax to set the inputs and finish with build().
Passport
FTM Schema: Passport
PassportBuilder
Use builder syntax to set the inputs and finish with build().
Payment
FTM Schema: Payment
PaymentBuilder
Use builder syntax to set the inputs and finish with build().
Person
FTM Schema: Person
PersonBuilder
Use builder syntax to set the inputs and finish with build().
PlainText
FTM Schema: Text file
PlainTextBuilder
Use builder syntax to set the inputs and finish with build().
Position
FTM Schema: Position
PositionBuilder
Use builder syntax to set the inputs and finish with build().
Project
FTM Schema: Project
ProjectBuilder
Use builder syntax to set the inputs and finish with build().
ProjectParticipant
FTM Schema: Project participant
ProjectParticipantBuilder
Use builder syntax to set the inputs and finish with build().
PublicBody
FTM Schema: Public body
PublicBodyBuilder
Use builder syntax to set the inputs and finish with build().
RealEstate
FTM Schema: Real estate
RealEstateBuilder
Use builder syntax to set the inputs and finish with build().
Representation
FTM Schema: Representation
RepresentationBuilder
Use builder syntax to set the inputs and finish with build().
Risk
FTM Schema: Risk
RiskBuilder
Use builder syntax to set the inputs and finish with build().
Sanction
FTM Schema: Sanction
SanctionBuilder
Use builder syntax to set the inputs and finish with build().
Security
FTM Schema: Security
SecurityBuilder
Use builder syntax to set the inputs and finish with build().
Similar
FTM Schema: Similar
SimilarBuilder
Use builder syntax to set the inputs and finish with build().
Succession
FTM Schema: Succession
SuccessionBuilder
Use builder syntax to set the inputs and finish with build().
Table
FTM Schema: Table
TableBuilder
Use builder syntax to set the inputs and finish with build().
TaxRoll
FTM Schema: Tax roll
TaxRollBuilder
Use builder syntax to set the inputs and finish with build().
Trip
FTM Schema: Trip
TripBuilder
Use builder syntax to set the inputs and finish with build().
UnknownLink
FTM Schema: Other link
UnknownLinkBuilder
Use builder syntax to set the inputs and finish with build().
UserAccount
FTM Schema: User account
UserAccountBuilder
Use builder syntax to set the inputs and finish with build().
Vehicle
FTM Schema: Vehicle
VehicleBuilder
Use builder syntax to set the inputs and finish with build().
Vessel
FTM Schema: Vessel
VesselBuilder
Use builder syntax to set the inputs and finish with build().
Video
FTM Schema: Video
VideoBuilder
Use builder syntax to set the inputs and finish with build().
Workbook
FTM Schema: Workbook
WorkbookBuilder
Use builder syntax to set the inputs and finish with build().