CallForTendersBuilder

Struct CallForTendersBuilder 

pub struct CallForTendersBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> CallForTendersBuilder<S>

pub fn build(self) -> CallForTenders
where S: IsComplete,

Finish building and return the requested object

pub fn id(self, value: String) -> CallForTendersBuilder<SetId<S>>
where S::Id: IsUnset,

Required.

pub fn schema(self, value: String) -> CallForTendersBuilder<SetSchema<S>>
where S::Schema: IsUnset,

Optional (Some / Option setters). Default: "CallForTenders".to_string().

pub fn maybe_schema( self, value: Option<String>, ) -> CallForTendersBuilder<SetSchema<S>>
where S::Schema: IsUnset,

Optional (Some / Option setters). Default: "CallForTenders".to_string().

pub fn address( self, value: impl Into<String>, ) -> CallForTendersBuilder<SetAddress<S>>
where S::Address: IsUnset,

Optional (Some / Option setters). Property: Address

pub fn maybe_address( self, value: Option<impl Into<String>>, ) -> CallForTendersBuilder<SetAddress<S>>
where S::Address: IsUnset,

Optional (Some / Option setters). Property: Address

pub fn address_entity( self, value: impl Into<String>, ) -> CallForTendersBuilder<SetAddressEntity<S>>
where S::AddressEntity: IsUnset,

Optional (Some / Option setters). Property: Address

pub fn maybe_address_entity( self, value: Option<impl Into<String>>, ) -> CallForTendersBuilder<SetAddressEntity<S>>
where S::AddressEntity: IsUnset,

Optional (Some / Option setters). Property: Address

pub fn aleph_url( self, value: impl Into<String>, ) -> CallForTendersBuilder<SetAlephUrl<S>>
where S::AlephUrl: IsUnset,

Optional (Some / Option setters). Property: Aleph URL

pub fn maybe_aleph_url( self, value: Option<impl Into<String>>, ) -> CallForTendersBuilder<SetAlephUrl<S>>
where S::AlephUrl: IsUnset,

Optional (Some / Option setters). Property: Aleph URL

pub fn alias( self, value: impl Into<String>, ) -> CallForTendersBuilder<SetAlias<S>>
where S::Alias: IsUnset,

Optional (Some / Option setters). Property: Alias

pub fn maybe_alias( self, value: Option<impl Into<String>>, ) -> CallForTendersBuilder<SetAlias<S>>
where S::Alias: IsUnset,

Optional (Some / Option setters). Property: Alias

pub fn authority( self, value: impl Into<String>, ) -> CallForTendersBuilder<SetAuthority<S>>
where S::Authority: IsUnset,

Required.

Property: Name of contracting authority

pub fn authority_reference_id( self, value: impl Into<String>, ) -> CallForTendersBuilder<SetAuthorityReferenceId<S>>
where S::AuthorityReferenceId: IsUnset,

Optional (Some / Option setters). Property: Contracting authority reference ID

pub fn maybe_authority_reference_id( self, value: Option<impl Into<String>>, ) -> CallForTendersBuilder<SetAuthorityReferenceId<S>>
where S::AuthorityReferenceId: IsUnset,

Optional (Some / Option setters). Property: Contracting authority reference ID

pub fn award_notice_date( self, value: impl Into<String>, ) -> CallForTendersBuilder<SetAwardNoticeDate<S>>
where S::AwardNoticeDate: IsUnset,

Optional (Some / Option setters). Property: Award Notice Date

pub fn maybe_award_notice_date( self, value: Option<impl Into<String>>, ) -> CallForTendersBuilder<SetAwardNoticeDate<S>>
where S::AwardNoticeDate: IsUnset,

Optional (Some / Option setters). Property: Award Notice Date

pub fn awarded_in_lots( self, value: impl Into<String>, ) -> CallForTendersBuilder<SetAwardedInLots<S>>
where S::AwardedInLots: IsUnset,

Optional (Some / Option setters). Property: Contract awarded in Lots

pub fn maybe_awarded_in_lots( self, value: Option<impl Into<String>>, ) -> CallForTendersBuilder<SetAwardedInLots<S>>
where S::AwardedInLots: IsUnset,

Optional (Some / Option setters). Property: Contract awarded in Lots

pub fn awarding_date( self, value: impl Into<String>, ) -> CallForTendersBuilder<SetAwardingDate<S>>
where S::AwardingDate: IsUnset,

Optional (Some / Option setters). Property: Date of awarding

pub fn maybe_awarding_date( self, value: Option<impl Into<String>>, ) -> CallForTendersBuilder<SetAwardingDate<S>>
where S::AwardingDate: IsUnset,

Optional (Some / Option setters). Property: Date of awarding

pub fn call_id( self, value: impl Into<String>, ) -> CallForTendersBuilder<SetCallId<S>>
where S::CallId: IsUnset,

Optional (Some / Option setters). Property: CfT unique id

pub fn maybe_call_id( self, value: Option<impl Into<String>>, ) -> CallForTendersBuilder<SetCallId<S>>
where S::CallId: IsUnset,

Optional (Some / Option setters). Property: CfT unique id

pub fn certification_check( self, value: impl Into<String>, ) -> CallForTendersBuilder<SetCertificationCheck<S>>
where S::CertificationCheck: IsUnset,

Optional (Some / Option setters). Property: Certification check

pub fn maybe_certification_check( self, value: Option<impl Into<String>>, ) -> CallForTendersBuilder<SetCertificationCheck<S>>
where S::CertificationCheck: IsUnset,

Optional (Some / Option setters). Property: Certification check

pub fn clarification_deadline( self, value: impl Into<String>, ) -> CallForTendersBuilder<SetClarificationDeadline<S>>
where S::ClarificationDeadline: IsUnset,

Optional (Some / Option setters). Property: End of clarification period

pub fn maybe_clarification_deadline( self, value: Option<impl Into<String>>, ) -> CallForTendersBuilder<SetClarificationDeadline<S>>
where S::ClarificationDeadline: IsUnset,

Optional (Some / Option setters). Property: End of clarification period

pub fn contract_notice_date( self, value: impl Into<String>, ) -> CallForTendersBuilder<SetContractNoticeDate<S>>
where S::ContractNoticeDate: IsUnset,

Optional (Some / Option setters). Property: Contract notice date

pub fn maybe_contract_notice_date( self, value: Option<impl Into<String>>, ) -> CallForTendersBuilder<SetContractNoticeDate<S>>
where S::ContractNoticeDate: IsUnset,

Optional (Some / Option setters). Property: Contract notice date

pub fn country( self, value: impl Into<String>, ) -> CallForTendersBuilder<SetCountry<S>>
where S::Country: IsUnset,

Optional (Some / Option setters). Property: Country

pub fn maybe_country( self, value: Option<impl Into<String>>, ) -> CallForTendersBuilder<SetCountry<S>>
where S::Country: IsUnset,

Optional (Some / Option setters). Property: Country

pub fn cpv_code( self, value: impl Into<String>, ) -> CallForTendersBuilder<SetCpvCode<S>>
where S::CpvCode: IsUnset,

Optional (Some / Option setters). Property: CPV code

pub fn maybe_cpv_code( self, value: Option<impl Into<String>>, ) -> CallForTendersBuilder<SetCpvCode<S>>
where S::CpvCode: IsUnset,

Optional (Some / Option setters). Property: CPV code

pub fn created_at( self, value: impl Into<String>, ) -> CallForTendersBuilder<SetCreatedAt<S>>
where S::CreatedAt: IsUnset,

Optional (Some / Option setters). Property: Created at

pub fn maybe_created_at( self, value: Option<impl Into<String>>, ) -> CallForTendersBuilder<SetCreatedAt<S>>
where S::CreatedAt: IsUnset,

Optional (Some / Option setters). Property: Created at

pub fn date(self, value: impl Into<String>) -> CallForTendersBuilder<SetDate<S>>
where S::Date: IsUnset,

Optional (Some / Option setters). Property: Date

pub fn maybe_date( self, value: Option<impl Into<String>>, ) -> CallForTendersBuilder<SetDate<S>>
where S::Date: IsUnset,

Optional (Some / Option setters). Property: Date

pub fn description( self, value: impl Into<String>, ) -> CallForTendersBuilder<SetDescription<S>>
where S::Description: IsUnset,

Optional (Some / Option setters). Property: Description

pub fn maybe_description( self, value: Option<impl Into<String>>, ) -> CallForTendersBuilder<SetDescription<S>>
where S::Description: IsUnset,

Optional (Some / Option setters). Property: Description

pub fn directive( self, value: impl Into<String>, ) -> CallForTendersBuilder<SetDirective<S>>
where S::Directive: IsUnset,

Optional (Some / Option setters). Property: Directive

pub fn maybe_directive( self, value: Option<impl Into<String>>, ) -> CallForTendersBuilder<SetDirective<S>>
where S::Directive: IsUnset,

Optional (Some / Option setters). Property: Directive

pub fn end_date( self, value: impl Into<String>, ) -> CallForTendersBuilder<SetEndDate<S>>
where S::EndDate: IsUnset,

Optional (Some / Option setters). Property: End date

pub fn maybe_end_date( self, value: Option<impl Into<String>>, ) -> CallForTendersBuilder<SetEndDate<S>>
where S::EndDate: IsUnset,

Optional (Some / Option setters). Property: End date

pub fn eu_funding( self, value: impl Into<String>, ) -> CallForTendersBuilder<SetEuFunding<S>>
where S::EuFunding: IsUnset,

Optional (Some / Option setters). Property: EU funding

pub fn maybe_eu_funding( self, value: Option<impl Into<String>>, ) -> CallForTendersBuilder<SetEuFunding<S>>
where S::EuFunding: IsUnset,

Optional (Some / Option setters). Property: EU funding

pub fn evaluation_mechanism( self, value: impl Into<String>, ) -> CallForTendersBuilder<SetEvaluationMechanism<S>>
where S::EvaluationMechanism: IsUnset,

Optional (Some / Option setters). Property: Evaluation mechanism

pub fn maybe_evaluation_mechanism( self, value: Option<impl Into<String>>, ) -> CallForTendersBuilder<SetEvaluationMechanism<S>>
where S::EvaluationMechanism: IsUnset,

Optional (Some / Option setters). Property: Evaluation mechanism

pub fn falls_under_gppscope( self, value: impl Into<String>, ) -> CallForTendersBuilder<SetFallsUnderGppscope<S>>
where S::FallsUnderGppscope: IsUnset,

Optional (Some / Option setters). Property: Does this call fall under the scope of GPP?

pub fn maybe_falls_under_gppscope( self, value: Option<impl Into<String>>, ) -> CallForTendersBuilder<SetFallsUnderGppscope<S>>
where S::FallsUnderGppscope: IsUnset,

Optional (Some / Option setters). Property: Does this call fall under the scope of GPP?

pub fn index_text( self, value: impl Into<String>, ) -> CallForTendersBuilder<SetIndexText<S>>
where S::IndexText: IsUnset,

Optional (Some / Option setters). Property: Index text

pub fn maybe_index_text( self, value: Option<impl Into<String>>, ) -> CallForTendersBuilder<SetIndexText<S>>
where S::IndexText: IsUnset,

Optional (Some / Option setters). Property: Index text

pub fn involves_outcome( self, value: impl Into<String>, ) -> CallForTendersBuilder<SetInvolvesOutcome<S>>
where S::InvolvesOutcome: IsUnset,

Optional (Some / Option setters). Property: Call for tenders result

pub fn maybe_involves_outcome( self, value: Option<impl Into<String>>, ) -> CallForTendersBuilder<SetInvolvesOutcome<S>>
where S::InvolvesOutcome: IsUnset,

Optional (Some / Option setters). Property: Call for tenders result

pub fn keywords( self, value: impl Into<String>, ) -> CallForTendersBuilder<SetKeywords<S>>
where S::Keywords: IsUnset,

Optional (Some / Option setters). Property: Keywords

pub fn maybe_keywords( self, value: Option<impl Into<String>>, ) -> CallForTendersBuilder<SetKeywords<S>>
where S::Keywords: IsUnset,

Optional (Some / Option setters). Property: Keywords

pub fn lots_names( self, value: impl Into<String>, ) -> CallForTendersBuilder<SetLotsNames<S>>
where S::LotsNames: IsUnset,

Optional (Some / Option setters). Property: Lots names

pub fn maybe_lots_names( self, value: Option<impl Into<String>>, ) -> CallForTendersBuilder<SetLotsNames<S>>
where S::LotsNames: IsUnset,

Optional (Some / Option setters). Property: Lots names

pub fn maximum_number_of_lots( self, value: f64, ) -> CallForTendersBuilder<SetMaximumNumberOfLots<S>>
where S::MaximumNumberOfLots: IsUnset,

Optional (Some / Option setters). Property: Maximum number of lots

pub fn maybe_maximum_number_of_lots( self, value: Option<f64>, ) -> CallForTendersBuilder<SetMaximumNumberOfLots<S>>
where S::MaximumNumberOfLots: IsUnset,

Optional (Some / Option setters). Property: Maximum number of lots

pub fn modified_at( self, value: impl Into<String>, ) -> CallForTendersBuilder<SetModifiedAt<S>>
where S::ModifiedAt: IsUnset,

Optional (Some / Option setters). Property: Modified on

pub fn maybe_modified_at( self, value: Option<impl Into<String>>, ) -> CallForTendersBuilder<SetModifiedAt<S>>
where S::ModifiedAt: IsUnset,

Optional (Some / Option setters). Property: Modified on

pub fn multiple_tenders( self, value: impl Into<String>, ) -> CallForTendersBuilder<SetMultipleTenders<S>>
where S::MultipleTenders: IsUnset,

Optional (Some / Option setters). Property: Multiple tenders will be accepted

pub fn maybe_multiple_tenders( self, value: Option<impl Into<String>>, ) -> CallForTendersBuilder<SetMultipleTenders<S>>
where S::MultipleTenders: IsUnset,

Optional (Some / Option setters). Property: Multiple tenders will be accepted

pub fn name(self, value: impl Into<String>) -> CallForTendersBuilder<SetName<S>>
where S::Name: IsUnset,

Required.

Property: Name

pub fn names_mentioned( self, value: impl Into<String>, ) -> CallForTendersBuilder<SetNamesMentioned<S>>
where S::NamesMentioned: IsUnset,

Optional (Some / Option setters). Property: Detected names

pub fn maybe_names_mentioned( self, value: Option<impl Into<String>>, ) -> CallForTendersBuilder<SetNamesMentioned<S>>
where S::NamesMentioned: IsUnset,

Optional (Some / Option setters). Property: Detected names

pub fn notes( self, value: impl Into<String>, ) -> CallForTendersBuilder<SetNotes<S>>
where S::Notes: IsUnset,

Optional (Some / Option setters). Property: Notes

pub fn maybe_notes( self, value: Option<impl Into<String>>, ) -> CallForTendersBuilder<SetNotes<S>>
where S::Notes: IsUnset,

Optional (Some / Option setters). Property: Notes

pub fn number_of_lots( self, value: f64, ) -> CallForTendersBuilder<SetNumberOfLots<S>>
where S::NumberOfLots: IsUnset,

Optional (Some / Option setters). Property: Number of lots

pub fn maybe_number_of_lots( self, value: Option<f64>, ) -> CallForTendersBuilder<SetNumberOfLots<S>>
where S::NumberOfLots: IsUnset,

Optional (Some / Option setters). Property: Number of lots

pub fn nuts_code( self, value: impl Into<String>, ) -> CallForTendersBuilder<SetNutsCode<S>>
where S::NutsCode: IsUnset,

Optional (Some / Option setters). Property: NUTS code

pub fn maybe_nuts_code( self, value: Option<impl Into<String>>, ) -> CallForTendersBuilder<SetNutsCode<S>>
where S::NutsCode: IsUnset,

Optional (Some / Option setters). Property: NUTS code

pub fn on_behalf_of( self, value: impl Into<String>, ) -> CallForTendersBuilder<SetOnBehalfOf<S>>
where S::OnBehalfOf: IsUnset,

Optional (Some / Option setters). Property: Published on behalf of

pub fn maybe_on_behalf_of( self, value: Option<impl Into<String>>, ) -> CallForTendersBuilder<SetOnBehalfOf<S>>
where S::OnBehalfOf: IsUnset,

Optional (Some / Option setters). Property: Published on behalf of

pub fn payment_options( self, value: impl Into<String>, ) -> CallForTendersBuilder<SetPaymentOptions<S>>
where S::PaymentOptions: IsUnset,

Optional (Some / Option setters). Property: Payment options

pub fn maybe_payment_options( self, value: Option<impl Into<String>>, ) -> CallForTendersBuilder<SetPaymentOptions<S>>
where S::PaymentOptions: IsUnset,

Optional (Some / Option setters). Property: Payment options

pub fn previous_name( self, value: impl Into<String>, ) -> CallForTendersBuilder<SetPreviousName<S>>
where S::PreviousName: IsUnset,

Optional (Some / Option setters). Property: Previous name

pub fn maybe_previous_name( self, value: Option<impl Into<String>>, ) -> CallForTendersBuilder<SetPreviousName<S>>
where S::PreviousName: IsUnset,

Optional (Some / Option setters). Property: Previous name

pub fn procedure( self, value: impl Into<String>, ) -> CallForTendersBuilder<SetProcedure<S>>
where S::Procedure: IsUnset,

Optional (Some / Option setters). Property: Procedure

pub fn maybe_procedure( self, value: Option<impl Into<String>>, ) -> CallForTendersBuilder<SetProcedure<S>>
where S::Procedure: IsUnset,

Optional (Some / Option setters). Property: Procedure

pub fn procurement_type( self, value: impl Into<String>, ) -> CallForTendersBuilder<SetProcurementType<S>>
where S::ProcurementType: IsUnset,

Optional (Some / Option setters). Property: Procurement type

pub fn maybe_procurement_type( self, value: Option<impl Into<String>>, ) -> CallForTendersBuilder<SetProcurementType<S>>
where S::ProcurementType: IsUnset,

Optional (Some / Option setters). Property: Procurement type

pub fn program( self, value: impl Into<String>, ) -> CallForTendersBuilder<SetProgram<S>>
where S::Program: IsUnset,

Optional (Some / Option setters). Property: Program

pub fn maybe_program( self, value: Option<impl Into<String>>, ) -> CallForTendersBuilder<SetProgram<S>>
where S::Program: IsUnset,

Optional (Some / Option setters). Property: Program

pub fn program_id( self, value: impl Into<String>, ) -> CallForTendersBuilder<SetProgramId<S>>
where S::ProgramId: IsUnset,

Optional (Some / Option setters). Property: Program ID

pub fn maybe_program_id( self, value: Option<impl Into<String>>, ) -> CallForTendersBuilder<SetProgramId<S>>
where S::ProgramId: IsUnset,

Optional (Some / Option setters). Property: Program ID

pub fn proof( self, value: impl Into<String>, ) -> CallForTendersBuilder<SetProof<S>>
where S::Proof: IsUnset,

Optional (Some / Option setters). Property: Source document

pub fn maybe_proof( self, value: Option<impl Into<String>>, ) -> CallForTendersBuilder<SetProof<S>>
where S::Proof: IsUnset,

Optional (Some / Option setters). Property: Source document

pub fn publication_date( self, value: impl Into<String>, ) -> CallForTendersBuilder<SetPublicationDate<S>>
where S::PublicationDate: IsUnset,

Optional (Some / Option setters). Property: Date of publication/invitation

pub fn maybe_publication_date( self, value: Option<impl Into<String>>, ) -> CallForTendersBuilder<SetPublicationDate<S>>
where S::PublicationDate: IsUnset,

Optional (Some / Option setters). Property: Date of publication/invitation

pub fn publisher( self, value: impl Into<String>, ) -> CallForTendersBuilder<SetPublisher<S>>
where S::Publisher: IsUnset,

Optional (Some / Option setters). Property: Publishing source

pub fn maybe_publisher( self, value: Option<impl Into<String>>, ) -> CallForTendersBuilder<SetPublisher<S>>
where S::Publisher: IsUnset,

Optional (Some / Option setters). Property: Publishing source

pub fn publisher_url( self, value: impl Into<String>, ) -> CallForTendersBuilder<SetPublisherUrl<S>>
where S::PublisherUrl: IsUnset,

Optional (Some / Option setters). Property: Publishing source URL

pub fn maybe_publisher_url( self, value: Option<impl Into<String>>, ) -> CallForTendersBuilder<SetPublisherUrl<S>>
where S::PublisherUrl: IsUnset,

Optional (Some / Option setters). Property: Publishing source URL

pub fn record_id( self, value: impl Into<String>, ) -> CallForTendersBuilder<SetRecordId<S>>
where S::RecordId: IsUnset,

Optional (Some / Option setters). Property: Record ID

pub fn maybe_record_id( self, value: Option<impl Into<String>>, ) -> CallForTendersBuilder<SetRecordId<S>>
where S::RecordId: IsUnset,

Optional (Some / Option setters). Property: Record ID

pub fn relation_to_threshold( self, value: impl Into<String>, ) -> CallForTendersBuilder<SetRelationToThreshold<S>>
where S::RelationToThreshold: IsUnset,

Optional (Some / Option setters). Property: Above or below threshold

pub fn maybe_relation_to_threshold( self, value: Option<impl Into<String>>, ) -> CallForTendersBuilder<SetRelationToThreshold<S>>
where S::RelationToThreshold: IsUnset,

Optional (Some / Option setters). Property: Above or below threshold

pub fn retrieved_at( self, value: impl Into<String>, ) -> CallForTendersBuilder<SetRetrievedAt<S>>
where S::RetrievedAt: IsUnset,

Optional (Some / Option setters). Property: Retrieved on

pub fn maybe_retrieved_at( self, value: Option<impl Into<String>>, ) -> CallForTendersBuilder<SetRetrievedAt<S>>
where S::RetrievedAt: IsUnset,

Optional (Some / Option setters). Property: Retrieved on

pub fn reverse_auctions_included( self, value: impl Into<String>, ) -> CallForTendersBuilder<SetReverseAuctionsIncluded<S>>
where S::ReverseAuctionsIncluded: IsUnset,

Optional (Some / Option setters). Property: Inclusion of e-Auctions

pub fn maybe_reverse_auctions_included( self, value: Option<impl Into<String>>, ) -> CallForTendersBuilder<SetReverseAuctionsIncluded<S>>
where S::ReverseAuctionsIncluded: IsUnset,

Optional (Some / Option setters). Property: Inclusion of e-Auctions

pub fn source_url( self, value: impl Into<String>, ) -> CallForTendersBuilder<SetSourceUrl<S>>
where S::SourceUrl: IsUnset,

Optional (Some / Option setters). Property: Source link

pub fn maybe_source_url( self, value: Option<impl Into<String>>, ) -> CallForTendersBuilder<SetSourceUrl<S>>
where S::SourceUrl: IsUnset,

Optional (Some / Option setters). Property: Source link

pub fn start_date( self, value: impl Into<String>, ) -> CallForTendersBuilder<SetStartDate<S>>
where S::StartDate: IsUnset,

Optional (Some / Option setters). Property: Start date

pub fn maybe_start_date( self, value: Option<impl Into<String>>, ) -> CallForTendersBuilder<SetStartDate<S>>
where S::StartDate: IsUnset,

Optional (Some / Option setters). Property: Start date

pub fn submission_deadline( self, value: impl Into<String>, ) -> CallForTendersBuilder<SetSubmissionDeadline<S>>
where S::SubmissionDeadline: IsUnset,

Optional (Some / Option setters). Property: Submission deadline

pub fn maybe_submission_deadline( self, value: Option<impl Into<String>>, ) -> CallForTendersBuilder<SetSubmissionDeadline<S>>
where S::SubmissionDeadline: IsUnset,

Optional (Some / Option setters). Property: Submission deadline

pub fn summary( self, value: impl Into<String>, ) -> CallForTendersBuilder<SetSummary<S>>
where S::Summary: IsUnset,

Optional (Some / Option setters). Property: Summary

pub fn maybe_summary( self, value: Option<impl Into<String>>, ) -> CallForTendersBuilder<SetSummary<S>>
where S::Summary: IsUnset,

Optional (Some / Option setters). Property: Summary

pub fn ted_url( self, value: impl Into<String>, ) -> CallForTendersBuilder<SetTedUrl<S>>
where S::TedUrl: IsUnset,

Optional (Some / Option setters). Property: TED link for published notices

pub fn maybe_ted_url( self, value: Option<impl Into<String>>, ) -> CallForTendersBuilder<SetTedUrl<S>>
where S::TedUrl: IsUnset,

Optional (Some / Option setters). Property: TED link for published notices

pub fn tenderers( self, value: impl Into<String>, ) -> CallForTendersBuilder<SetTenderers<S>>
where S::Tenderers: IsUnset,

Optional (Some / Option setters). Property: Tenderers

pub fn maybe_tenderers( self, value: Option<impl Into<String>>, ) -> CallForTendersBuilder<SetTenderers<S>>
where S::Tenderers: IsUnset,

Optional (Some / Option setters). Property: Tenderers

pub fn tenders_for_lots( self, value: impl Into<String>, ) -> CallForTendersBuilder<SetTendersForLots<S>>
where S::TendersForLots: IsUnset,

Optional (Some / Option setters). Property: Tenders for lots

pub fn maybe_tenders_for_lots( self, value: Option<impl Into<String>>, ) -> CallForTendersBuilder<SetTendersForLots<S>>
where S::TendersForLots: IsUnset,

Optional (Some / Option setters). Property: Tenders for lots

pub fn title( self, value: impl Into<String>, ) -> CallForTendersBuilder<SetTitle<S>>
where S::Title: IsUnset,

Required.

Property: Title

pub fn topics( self, value: impl Into<String>, ) -> CallForTendersBuilder<SetTopics<S>>
where S::Topics: IsUnset,

Optional (Some / Option setters). Property: Topics

pub fn maybe_topics( self, value: Option<impl Into<String>>, ) -> CallForTendersBuilder<SetTopics<S>>
where S::Topics: IsUnset,

Optional (Some / Option setters). Property: Topics

pub fn weak_alias( self, value: impl Into<String>, ) -> CallForTendersBuilder<SetWeakAlias<S>>
where S::WeakAlias: IsUnset,

Optional (Some / Option setters). Property: Weak alias

pub fn maybe_weak_alias( self, value: Option<impl Into<String>>, ) -> CallForTendersBuilder<SetWeakAlias<S>>
where S::WeakAlias: IsUnset,

Optional (Some / Option setters). Property: Weak alias

pub fn wikidata_id( self, value: impl Into<String>, ) -> CallForTendersBuilder<SetWikidataId<S>>
where S::WikidataId: IsUnset,

Optional (Some / Option setters). Property: Wikidata ID

pub fn maybe_wikidata_id( self, value: Option<impl Into<String>>, ) -> CallForTendersBuilder<SetWikidataId<S>>
where S::WikidataId: IsUnset,

Optional (Some / Option setters). Property: Wikidata ID

pub fn wikipedia_url( self, value: impl Into<String>, ) -> CallForTendersBuilder<SetWikipediaUrl<S>>
where S::WikipediaUrl: IsUnset,

Optional (Some / Option setters). Property: Wikipedia Article

pub fn maybe_wikipedia_url( self, value: Option<impl Into<String>>, ) -> CallForTendersBuilder<SetWikipediaUrl<S>>
where S::WikipediaUrl: IsUnset,

Optional (Some / Option setters). Property: Wikipedia Article