FtmEntity

Enum FtmEntity 

pub enum FtmEntity {
Show 64 variants Address(Address), Airplane(Airplane), Article(Article), Asset(Asset), Associate(Associate), Audio(Audio), BankAccount(BankAccount), Call(Call), CallForTenders(CallForTenders), Company(Company), Contract(Contract), ContractAward(ContractAward), CourtCase(CourtCase), CourtCaseParty(CourtCaseParty), CryptoWallet(CryptoWallet), Debt(Debt), Directorship(Directorship), Document(Document), Documentation(Documentation), EconomicActivity(EconomicActivity), Email(Email), Employment(Employment), Event(Event), Family(Family), Folder(Folder), HyperText(HyperText), Identification(Identification), Image(Image), LegalEntity(LegalEntity), License(License), Membership(Membership), Mention(Mention), Message(Message), Note(Note), Occupancy(Occupancy), Organization(Organization), Ownership(Ownership), Package(Package), Page(Page), Pages(Pages), Passport(Passport), Payment(Payment), Person(Person), PlainText(PlainText), Position(Position), Project(Project), ProjectParticipant(ProjectParticipant), PublicBody(PublicBody), RealEstate(RealEstate), Representation(Representation), Risk(Risk), Sanction(Sanction), Security(Security), Similar(Similar), Succession(Succession), Table(Table), TaxRoll(TaxRoll), Trip(Trip), UnknownLink(UnknownLink), UserAccount(UserAccount), Vehicle(Vehicle), Vessel(Vessel), Video(Video), Workbook(Workbook),
}
FTM Entity enum for runtime polymorphism

Variants



Address(Address)



Airplane(Airplane)



Article(Article)



Asset(Asset)



Associate(Associate)



Audio(Audio)



BankAccount(BankAccount)



Call(Call)



CallForTenders(CallForTenders)



Company(Company)



Contract(Contract)



ContractAward(ContractAward)



CourtCase(CourtCase)



CourtCaseParty(CourtCaseParty)



CryptoWallet(CryptoWallet)



Debt(Debt)



Directorship(Directorship)



Document(Document)



Documentation(Documentation)



EconomicActivity(EconomicActivity)



Email(Email)



Employment(Employment)



Event(Event)



Family(Family)



Folder(Folder)



HyperText(HyperText)



Identification(Identification)



Image(Image)



LegalEntity(LegalEntity)



License(License)



Membership(Membership)



Mention(Mention)



Message(Message)



Note(Note)



Occupancy(Occupancy)



Organization(Organization)



Ownership(Ownership)



Package(Package)



Page(Page)



Pages(Pages)



Passport(Passport)



Payment(Payment)



Person(Person)



PlainText(PlainText)



Position(Position)



Project(Project)



ProjectParticipant(ProjectParticipant)



PublicBody(PublicBody)



RealEstate(RealEstate)



Representation(Representation)



Risk(Risk)



Sanction(Sanction)



Security(Security)



Similar(Similar)



Succession(Succession)



Table(Table)



TaxRoll(TaxRoll)



Trip(Trip)



UserAccount(UserAccount)



Vehicle(Vehicle)



Vessel(Vessel)



Video(Video)



Workbook(Workbook)

Implementations

Source

impl FtmEntity

pub fn schema(&self) -> &str

Get the schema name for this entity

pub fn id(&self) -> &str

Get the entity ID

pub fn from_ftm_json(json_str: &str) -> Result<Self, Error>

Parse FTM entity from nested JSON format

The standard FTM JSON format has a nested structure:

{
  "id": "...",
  "schema": "Payment",
  "properties": {
    "amount": ["100"],
    "date": ["2024-01-01"]
  }
}

This function flattens the structure to match the generated Rust types. Dispatch is done on the "schema" field, so the correct variant is always selected regardless of declaration order in the enum.

pub fn to_ftm_json(&self) -> Result<String, Error>

Serialize to standard FTM nested JSON format

Produces {"id": "...", "schema": "...", "properties": {...}}