Analyzable

Trait Analyzable 

pub trait Analyzable {
    // Required methods
    fn id(&self) -> &str;
    fn schema(&self) -> &str;
    fn companies_mentioned(&self) -> Option<&[String]>;
    fn detected_country(&self) -> Option<&[String]>;
    fn detected_language(&self) -> Option<&[String]>;
    fn email_mentioned(&self) -> Option<&[String]>;
    fn iban_mentioned(&self) -> Option<&[String]>;
    fn ip_mentioned(&self) -> Option<&[String]>;
    fn location_mentioned(&self) -> Option<&[String]>;
    fn names_mentioned(&self) -> Option<&[String]>;
    fn people_mentioned(&self) -> Option<&[String]>;
    fn phone_mentioned(&self) -> Option<&[String]>;
}
Traits representing FTM schema inheritance hierarchy.

These traits enable polymorphic code that works across entity types. All concrete entity structs implement the traits for their parent schemas. Trait for FTM schema: Analyzable

Required Methods

fn id(&self) -> &str

Get the entity ID

fn schema(&self) -> &str

Get the schema name

fn companies_mentioned(&self) -> Option<&[String]>

Get Detected companies property

fn detected_country(&self) -> Option<&[String]>

Get Detected country property

fn detected_language(&self) -> Option<&[String]>

Get Detected language property

fn email_mentioned(&self) -> Option<&[String]>

Get Detected e-mail addresses property

fn iban_mentioned(&self) -> Option<&[String]>

Get Detected IBANs property

fn ip_mentioned(&self) -> Option<&[String]>

Get Detected IP addresses property

fn location_mentioned(&self) -> Option<&[String]>

Get Detected locations property

fn names_mentioned(&self) -> Option<&[String]>

Get Detected names property

fn people_mentioned(&self) -> Option<&[String]>

Get Detected people property

fn phone_mentioned(&self) -> Option<&[String]>

Get Detected phones property

Implementors