Structs
- Address
- FTM Schema: Address
- Address
Builder - Use builder syntax to set the inputs and finish with
build(). - Airplane
- FTM Schema: Airplane
- Airplane
Builder - Use builder syntax to set the inputs and finish with
build(). - Article
- FTM Schema: Article
- Article
Builder - Use builder syntax to set the inputs and finish with
build(). - Asset
- FTM Schema: Asset
- Asset
Builder - Use builder syntax to set the inputs and finish with
build(). - Associate
- FTM Schema: Associate
- Associate
Builder - Use builder syntax to set the inputs and finish with
build(). - Audio
- FTM Schema: Audio
- Audio
Builder - Use builder syntax to set the inputs and finish with
build(). - Bank
Account - FTM Schema: Bank account
- Bank
Account Builder - Use builder syntax to set the inputs and finish with
build(). - Call
- FTM Schema: Call
- Call
Builder - Use builder syntax to set the inputs and finish with
build(). - Call
ForTenders - FTM Schema: Call for tenders
- Call
ForTenders Builder - Use builder syntax to set the inputs and finish with
build(). - Company
- FTM Schema: Company
- Company
Builder - Use builder syntax to set the inputs and finish with
build(). - Contract
- FTM Schema: Contract
- Contract
Award - FTM Schema: Contract award
- Contract
Award Builder - Use builder syntax to set the inputs and finish with
build(). - Contract
Builder - Use builder syntax to set the inputs and finish with
build(). - Court
Case - FTM Schema: Court case
- Court
Case Builder - Use builder syntax to set the inputs and finish with
build(). - Court
Case Party - FTM Schema: Case party
- Court
Case Party Builder - Use builder syntax to set the inputs and finish with
build(). - Crypto
Wallet - FTM Schema: Cryptocurrency wallet
- Crypto
Wallet Builder - Use builder syntax to set the inputs and finish with
build(). - Debt
- FTM Schema: Debt
- Debt
Builder - Use builder syntax to set the inputs and finish with
build(). - Directorship
- FTM Schema: Directorship
- Directorship
Builder - Use builder syntax to set the inputs and finish with
build(). - Document
- FTM Schema: File
- Document
Builder - Use builder syntax to set the inputs and finish with
build(). - Documentation
- FTM Schema: Documentation
- Documentation
Builder - Use builder syntax to set the inputs and finish with
build(). - Economic
Activity - FTM Schema: Customs declaration
- Economic
Activity Builder - Use builder syntax to set the inputs and finish with
build(). - FTM Schema: E-Mail
- Email
Builder - Use builder syntax to set the inputs and finish with
build(). - Employment
- FTM Schema: Employment
- Employment
Builder - Use builder syntax to set the inputs and finish with
build(). - Event
- FTM Schema: Event
- Event
Builder - Use builder syntax to set the inputs and finish with
build(). - Family
- FTM Schema: Family
- Family
Builder - Use builder syntax to set the inputs and finish with
build(). - Folder
- FTM Schema: Folder
- Folder
Builder - Use builder syntax to set the inputs and finish with
build(). - Hyper
Text - FTM Schema: Web page
- Hyper
Text Builder - Use builder syntax to set the inputs and finish with
build(). - Identification
- FTM Schema: Identification
- Identification
Builder - Use builder syntax to set the inputs and finish with
build(). - Image
- FTM Schema: Image
- Image
Builder - Use builder syntax to set the inputs and finish with
build(). - Legal
Entity - FTM Schema: Legal entity
- Legal
Entity Builder - Use builder syntax to set the inputs and finish with
build(). - License
- FTM Schema: License
- License
Builder - Use builder syntax to set the inputs and finish with
build(). - Membership
- FTM Schema: Membership
- Membership
Builder - Use builder syntax to set the inputs and finish with
build(). - Mention
- FTM Schema: Mention
- Mention
Builder - Use builder syntax to set the inputs and finish with
build(). - Message
- FTM Schema: Message
- Message
Builder - Use builder syntax to set the inputs and finish with
build(). - Note
- FTM Schema: Note
- Note
Builder - Use builder syntax to set the inputs and finish with
build(). - Occupancy
- FTM Schema: Occupancy
- Occupancy
Builder - Use builder syntax to set the inputs and finish with
build(). - Organization
- FTM Schema: Organization
- Organization
Builder - Use builder syntax to set the inputs and finish with
build(). - Ownership
- FTM Schema: Ownership
- Ownership
Builder - Use builder syntax to set the inputs and finish with
build(). - Package
- FTM Schema: Package
- Package
Builder - Use builder syntax to set the inputs and finish with
build(). - Page
- FTM Schema: Page
- Page
Builder - Use builder syntax to set the inputs and finish with
build(). - Pages
- FTM Schema: Document
- Pages
Builder - Use builder syntax to set the inputs and finish with
build(). - Passport
- FTM Schema: Passport
- Passport
Builder - Use builder syntax to set the inputs and finish with
build(). - Payment
- FTM Schema: Payment
- Payment
Builder - Use builder syntax to set the inputs and finish with
build(). - Person
- FTM Schema: Person
- Person
Builder - Use builder syntax to set the inputs and finish with
build(). - Plain
Text - FTM Schema: Text file
- Plain
Text Builder - Use builder syntax to set the inputs and finish with
build(). - Position
- FTM Schema: Position
- Position
Builder - Use builder syntax to set the inputs and finish with
build(). - Project
- FTM Schema: Project
- Project
Builder - Use builder syntax to set the inputs and finish with
build(). - Project
Participant - FTM Schema: Project participant
- Project
Participant Builder - Use builder syntax to set the inputs and finish with
build(). - Public
Body - FTM Schema: Public body
- Public
Body Builder - Use builder syntax to set the inputs and finish with
build(). - Real
Estate - FTM Schema: Real estate
- Real
Estate Builder - Use builder syntax to set the inputs and finish with
build(). - Representation
- FTM Schema: Representation
- Representation
Builder - Use builder syntax to set the inputs and finish with
build(). - Risk
- FTM Schema: Risk
- Risk
Builder - Use builder syntax to set the inputs and finish with
build(). - Sanction
- FTM Schema: Sanction
- Sanction
Builder - Use builder syntax to set the inputs and finish with
build(). - Security
- FTM Schema: Security
- Security
Builder - Use builder syntax to set the inputs and finish with
build(). - Similar
- FTM Schema: Similar
- Similar
Builder - Use builder syntax to set the inputs and finish with
build(). - Succession
- FTM Schema: Succession
- Succession
Builder - Use builder syntax to set the inputs and finish with
build(). - Table
- FTM Schema: Table
- Table
Builder - Use builder syntax to set the inputs and finish with
build(). - TaxRoll
- FTM Schema: Tax roll
- TaxRoll
Builder - Use builder syntax to set the inputs and finish with
build(). - Trip
- FTM Schema: Trip
- Trip
Builder - Use builder syntax to set the inputs and finish with
build(). - Unknown
Link - FTM Schema: Other link
- Unknown
Link Builder - Use builder syntax to set the inputs and finish with
build(). - User
Account - FTM Schema: User account
- User
Account Builder - Use builder syntax to set the inputs and finish with
build(). - Vehicle
- FTM Schema: Vehicle
- Vehicle
Builder - Use builder syntax to set the inputs and finish with
build(). - Vessel
- FTM Schema: Vessel
- Vessel
Builder - Use builder syntax to set the inputs and finish with
build(). - Video
- FTM Schema: Video
- Video
Builder - Use builder syntax to set the inputs and finish with
build(). - Workbook
- FTM Schema: Workbook
- Workbook
Builder - Use builder syntax to set the inputs and finish with
build().